Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2522)

Unified Diff: remoting/protocol/channel_factory.h

Issue 550383002: Cleanup ChannelFactory interface (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 6 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/protocol/channel_dispatcher_base.cc ('k') | remoting/protocol/channel_multiplexer.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/protocol/channel_factory.h
diff --git a/remoting/protocol/channel_factory.h b/remoting/protocol/channel_factory.h
index 7741e5d039b4a6b5473623f9cd724548302516a3..31bf3ec9df205cd5ebcac5f13eaf183ff50ef8f4 100644
--- a/remoting/protocol/channel_factory.h
+++ b/remoting/protocol/channel_factory.h
@@ -22,9 +22,7 @@ class ChannelFactory : public base::NonThreadSafe {
// TODO(sergeyu): Specify connection error code when channel
// connection fails.
typedef base::Callback<void(scoped_ptr<net::StreamSocket>)>
- StreamChannelCallback;
- typedef base::Callback<void(scoped_ptr<net::Socket>)>
- DatagramChannelCallback;
+ ChannelCreatedCallback;
ChannelFactory() {}
@@ -35,15 +33,12 @@ class ChannelFactory : public base::NonThreadSafe {
// before the factory is destroyed and CancelChannelCreation() must be called
// to cancel creation of channels for which the |callback| hasn't been called
// yet.
- virtual void CreateStreamChannel(
- const std::string& name, const StreamChannelCallback& callback) = 0;
- virtual void CreateDatagramChannel(
- const std::string& name, const DatagramChannelCallback& callback) = 0;
-
- // Cancels a pending CreateStreamChannel() or CreateDatagramChannel()
- // operation for the named channel. If the channel creation already
- // completed then canceling it has no effect. When shutting down
- // this method must be called for each channel pending creation.
+ virtual void CreateChannel(const std::string& name,
+ const ChannelCreatedCallback& callback) = 0;
+
+ // Cancels a pending CreateChannel() operation for the named channel. If the
+ // channel creation already completed then canceling it has no effect. When
+ // shutting down this method must be called for each channel pending creation.
virtual void CancelChannelCreation(const std::string& name) = 0;
protected:
« no previous file with comments | « remoting/protocol/channel_dispatcher_base.cc ('k') | remoting/protocol/channel_multiplexer.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698